from unicourt.api.attorney_analytics_api import AttorneyAnalyticsApi
from unicourt import utils
class AttorneyAnalytics:

    @staticmethod
    def get_norm_attorney_by_id(
        norm_attorney_id,
        **kwargs
    ):

        """Norm Attorney Details.  


        This endpoint retrieves information on the attorney in our normalized attorney database which matches the normAttorneyId specified in the request.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return AttorneyAnalyticsApi(api_client).get_norm_attorney_by_id(
        norm_attorney_id,
        **kwargs
    )

    @staticmethod
    def get_norm_judges_associated_with_norm_attorney(
        norm_attorney_id,
        **kwargs
    ):

        """Judges faced by the Attorney.  


        This endpoint returns information on all judges which have appeared in cases with the attorney specified by the normAttorneyId. The returned judges are ordered in descending order of number of cases shared with the relevant attorney. ## Terms and Connectors | Connector | Schema   | Description  | Example | | ------| ------| ------|------| | **AND** ||Find analytics containing all connected terms. The word AND does not have to be capitalized.|**courtId:\"CORTV4vCEaKrhystBz\"  AND  courtLocationId:\"COLO6b82CkRqS846hx\"**| | **IN()** || Allows you to specify multiple values, for a limit of up to 10.| **courtId IN (\"CORTV4vCEaKrhystBz\", \"CORTKQiA4LJuv54tEj\")**| | **courtId** | Multiple Ids Allowed |Find Analytics for a particular Court Object. | **courtId:\"CORTV4vCEaKrhystBz\"** | | **courtSystemId** | Multiple Ids Allowed  |Find Analytics for a particular Court System Object. | **courtSystemId:\"COSYACHBdMewtaG5DY\"** | | **courtTypeId** | Multiple Ids Allowed |Find Analytics for a particular Court Type Object. | **courtTypeId:\"COTPm8jjc2PAydpFhq\"** | | **courtLocationId** | Multiple Ids Allowed  |Find Analytics for a particular Court Location Object. | **courtLocationId:\"COLO6b82CkRqS846hx\"** | | **caseTypeId** | Multiple Ids Allowed  |Find Analytics for a particular Case Type Object. | **caseTypeId:\"CTYPGkaW3aGJyKGyfn\"** | | **caseTypeGroupId** | Multiple Ids Allowed  |Find Analytics for a particular Case Type Group Object. | **caseTypeGroupId:\"CTYGBDwLfbbNBPBn5e\"** | | **areaOfLawId** | Multiple Ids Allowed  |Find Analytics for a particular Area Of Law Object. | **areaOfLawId:\"AOFL2UxEWfVmTPMyqf\"** | | **caseClassId** | Multiple Ids Allowed  |Find Analytics for a particular Case Class Category Object. | **caseClassId:\"CSCLNjbKTN7Yfo2wdb\"** | | **caseFiledDate** | Single Allowed |Find Analytics within a particular date range. | **caseFiledDate:[2018-05-08T00:00:00+00:00TO2019-05-08T00:00:00+00:00]** | | **JurisdictionGeo** | Multiple filters Allowed |Find Analytics within a particular Jurisdiction Geo. | **(JurisdictionGeo:(state:\"California\"))** | | **confidenceScore** | Single Allowed |Find Analytics for a given ConfidenceScore  | **confidenceScore:[0.3 TO \\*]** | | **bestMatch** | Single Allowed |True if the normEntity has the highest Confidence Score of all possible normEntities | **bestMatch:true** | <br> ## Example Query Query to get all judges associated with attorney with norm id NATYfwmXwRHS279WPY of all cases with case type id CTYPGkaW3aGJyKGyfn and  case filed date between Jan 1st, 2017 to Nov 30th,2021<br> q=caseTypeId:\"CTYPGkaW3aGJyKGyfn\" AND caseFiledDate:[2017-01-01T00:00:00+00:00TO2021-11-30T00:00:00+00:00] <br><br>   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return AttorneyAnalyticsApi(api_client).get_norm_judges_associated_with_norm_attorney(
        norm_attorney_id,
        **kwargs
    )

    @staticmethod
    def get_norm_law_firms_associated_with_norm_attorney(
        norm_attorney_id,
        **kwargs
    ):

        """Law Firms the attorney has worked for.  


        Retrieve law firms with which the specified attorney is known to have been associated. ## Terms and Connectors | Connector | Schema   | Description  | Example | | ------| ------| ------|------| | **AND** ||Find analytics containing all connected terms. The word AND does not have to be capitalized.|**courtId:\"CORTV4vCEaKrhystBz\"  AND  courtLocationId:\"COLO6b82CkRqS846hx\"**| | **IN()** || Allows you to specify multiple values, for a limit of up to 10.| **courtId IN (\"CORTV4vCEaKrhystBz\", \"CORTKQiA4LJuv54tEj\")**| | **courtId** | Multiple Ids Allowed |Find Analytics for a particular Court Object. | **courtId:\"CORTV4vCEaKrhystBz\"** | | **courtSystemId** | Multiple Ids Allowed  |Find Analytics for a particular Court System Object. | **courtSystemId:\"COSYACHBdMewtaG5DY\"** | | **courtTypeId** | Multiple Ids Allowed  |Find Analytics for a particular Court Type Object. | **courtTypeId:\"COTPm8jjc2PAydpFhq\"** | | **courtLocationId** | Multiple Ids Allowed  |Find Analytics for a particular Court Location Object. | **courtLocationId:\"COLO6b82CkRqS846hx\"** | | **caseTypeId** | Multiple Ids Allowed  |Find Analytics for a particular Case Type Object. | **caseTypeId:\"CTYPGkaW3aGJyKGyfn\"** | | **caseTypeGroupId** | Multiple Ids Allowed  |Find Analytics for a particular Case Type Group Object. | **caseTypeGroupId:\"CTYGBDwLfbbNBPBn5e\"** | | **areaOfLawId** | Multiple Ids Allowed  |Find Analytics for a particular Area Of Law Object. | **areaOfLawId:\"AOFL2UxEWfVmTPMyqf\"** | | **caseClassId** | Multiple Ids Allowed  |Find Analytics for a particular Case Class Category Object. | **caseClassId:\"CSCLNjbKTN7Yfo2wdb\"** | | **partyRoleId** | Multiple Ids Allowed  |Find Analytics for a particular Party Type Object. | **partyRoleId:\"PTYRiP8nMgPxBsPc5i\"** | | **partyRoleGroupId** | Multiple Ids Allowed  |Find Analytics for a particular Party Type Group Object. | **partyRoleGroupId:\"PTYGBnjxbx6tKNfVEP\"** | | **attorneyPartyRoleId** | Multiple Ids Allowed  |Find Analytics for a particular Attorney Party Type Object. | **attorneyPartyRoleId:\"PTYRiP8nMgPxBsPc5i\"** | | **attorneyPartyRoleGroupId** | Multiple Ids Allowed  |Find Analytics for a particular Attorney Party Type Group Object. | **attorneyPartyRoleGroupId:\"PTYGBnjxbx6tKNfVEP\"** | | **caseFiledDate** | Single Allowed  |Find Analytics within a particular date range. | **caseFiledDate:[2018-05-08T00:00:00+00:00TO2019-05-08T00:00:00+00:00]** | | **JurisdictionGeo** | Multiple Ids Allowed  |Find Analytics within a particular Jurisdiction Geo. | **(JurisdictionGeo:(state:\"California\"))** | | **confidenceScore** | Single Allowed |Find Analytics for a given ConfidenceScore  | **confidenceScore:[0.3 TO \\*]** | | **bestMatch** | Single Allowed |True if the normEntity has the highest Confidence Score of all possible normEntities | **bestMatch:true** | <br> ## Example Query Query to get all LawFirms associated with attorney with norm id NATYfwmXwRHS279WPY of all cases with case type id CTYPGkaW3aGJyKGyfn and  case filed date between Jan 1st, 2017 to Nov 30th,2021<br> q=caseTypeId:\"CTYPGkaW3aGJyKGyfn\" AND caseFiledDate:[2017-01-01T00:00:00+00:00TO2021-11-30T00:00:00+00:00] <br><br>   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return AttorneyAnalyticsApi(api_client).get_norm_law_firms_associated_with_norm_attorney(
        norm_attorney_id,
        **kwargs
    )

    @staticmethod
    def get_norm_parties_associated_with_norm_attorney(
        norm_attorney_id,
        **kwargs
    ):

        """Parties Represented By the Attorney.  


        Retrieve the parties for which an attorney is known to have represented. <br><br> ## Terms and Connectors | Connector | Schema   | Description  | Example | | ------| ------| ------|------| | **AND** ||Find analytics containing all connected terms. The word AND does not have to be capitalized.|**courtId:\"CORTV4vCEaKrhystBz\"  AND  courtLocationId:\"COLO6b82CkRqS846hx\"**| | **IN()** || Allows you to specify multiple values, for a limit of up to 10.| **courtId IN (\"CORTV4vCEaKrhystBz\", \"CORTKQiA4LJuv54tEj\")**| | **courtId** | Multiple Ids Allowed  |Find Analytics for a particular Court Object. | **courtId:\"CORTV4vCEaKrhystBz\"** | | **courtSystemId** | Multiple Ids Allowed  |Find Analytics for a particular Court System Object. | **courtSystemId:\"COSYACHBdMewtaG5DY\"** | | **courtTypeId** | Multiple Ids Allowed  |Find Analytics for a particular Court Type Object. | **courtTypeId:\"COTPm8jjc2PAydpFhq\"** | | **courtLocationId** | Multiple Ids Allowed  |Find Analytics for a particular Court Location Object. | **courtLocationId:\"COLO6b82CkRqS846hx\"** | | **caseTypeId** | Multiple Ids Allowed  |Find Analytics for a particular Case Type Object. | **caseTypeId:\"CTYPGkaW3aGJyKGyfn\"** | | **caseTypeGroupId** | Multiple Ids Allowed  |Find Analytics for a particular Case Type Group Object. | **caseTypeGroupId:\"CTYGBDwLfbbNBPBn5e\"** | | **areaOfLawId** | Multiple Ids Allowed  |Find Analytics for a particular Area Of Law Object. | **areaOfLawId:\"AOFL2UxEWfVmTPMyqf\"** | | **caseClassId** | Multiple Ids Allowed  |Find Analytics for a particular Case Class Category Object. | **caseClassId:\"CSCLNjbKTN7Yfo2wdb\"** | | **partyRoleId** | Multiple Ids Allowed  |Find Analytics for a particular Party Type Object. | **partyRoleId:\"PTYRiP8nMgPxBsPc5i\"** | | **partyRoleGroupId** | Multiple Ids Allowed  |Find Analytics for a particular Party Type Group Object. | **partyRoleGroupId:\"PTYGBnjxbx6tKNfVEP\"** | | **attorneyPartyRoleId** | Multiple Ids Allowed  |Find Analytics for a particular Attorney Party Type Object. | **attorneyPartyRoleId:\"PTYRiP8nMgPxBsPc5i\"** | | **attorneyPartyRoleGroupId** | Multiple Ids Allowed  |Find Analytics for a particular Attorney Party Type Group Object.. | **attorneyPartyRoleGroupId:\"PTYGBnjxbx6tKNfVEP\"** | | **caseFiledDate** | Single Allowed   |Find Analytics within a particular date range. | **caseFiledDate:[2018-05-08T00:00:00+00:00TO2019-05-08T00:00:00+00:00]** | | **JurisdictionGeo** | Multiple Ids Allowed  |Find Analytics within a particular Jurisdiction Geo. | **(JurisdictionGeo:(state:\"California\"))** | | **confidenceScore** | Single Allowed |Find Analytics for a given ConfidenceScore  | **confidenceScore:[0.3 TO \\*]** | | **bestMatch** | Single Allowed |True if the normEntity has the highest Confidence Score of all possible normEntities | **bestMatch:true** | <br> ## Example Query Query to get all parties associated with attorney with norm id NATYfwmXwRHS279WPY of all cases with case type id CTYPGkaW3aGJyKGyfn and  case filed date between Jan 1st, 2017 to Nov 30th,2021<br> q=caseTypeId:\"CTYPGkaW3aGJyKGyfn\" AND caseFiledDate:[2017-01-01T00:00:00+00:00TO2021-11-30T00:00:00+00:00] <br><br>   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return AttorneyAnalyticsApi(api_client).get_norm_parties_associated_with_norm_attorney(
        norm_attorney_id,
        **kwargs
    )

    @staticmethod
    def search_normalized_attorneys(
        **kwargs
    ):

        """Attorney search.  


        ### This endpoint retrieves information, including the normAttorneyId, on all attorneys in our normalized attorney database which match the request parameters. All query parameters supported by this API can be found in the schema section below.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return AttorneyAnalyticsApi(api_client).search_normalized_attorneys(
        **kwargs
    )

    @staticmethod
    def search_normalized_attorneys_by_id(
        norm_attorney_search_id,
        **kwargs
    ):

        """Norm attorney search results for a given normAttorneySearchId.  


        ### All query parameters supported for this API can be found in below schema section. Schema --> NormAttorneySearchQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return AttorneyAnalyticsApi(api_client).search_normalized_attorneys_by_id(
        norm_attorney_search_id,
        **kwargs
    )



from unicourt.api.case_export_api import CaseExportApi
from unicourt import utils
class CaseExport:

    @staticmethod
    def export_case(
        case_id,
        **kwargs
    ):

        """Gets case exported for a requested Case ID.  


        Retrieve information about the specified case export.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseExportApi(api_client).export_case(
        case_id,
        **kwargs
    )

    @staticmethod
    def get_case_export_callback_by_id(
        case_export_callback_id,
        **kwargs
    ):

        """Get Case Export Callback for a requested Case Export Callback Id.  


        Retrieve the specified case export callback object.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseExportApi(api_client).get_case_export_callback_by_id(
        case_export_callback_id,
        **kwargs
    )

    @staticmethod
    def get_case_export_callbacks(
        **kwargs
    ):

        """Get Case Export Callback list for a requested Date.  


        Retrieve callbacks according to the specified criteria.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseExportApi(api_client).get_case_export_callbacks(
        **kwargs
    )



from unicourt.api.court_standards_api import CourtStandardsApi
from unicourt import utils
class CourtStandards:

    @staticmethod
    def get_appeal_courts_for_court(
        court_id,
        **kwargs
    ):

        """Appeal Court Objects for given courtId.  


        Retrieve the appeals courts associated with the specified court.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_appeal_courts_for_court(
        court_id,
        **kwargs
    )

    @staticmethod
    def get_area_of_law(
        area_of_law_id,
        **kwargs
    ):

        """AreaOfLaw Object for the given AreaOfLaw Id.  


        Retrieve the specified area of law.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_area_of_law(
        area_of_law_id,
        **kwargs
    )

    @staticmethod
    def get_areas_of_law(
        **kwargs
    ):

        """AreaOfLaw Object.  


        The keyword expression targeting the desired area of law.   ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> AreaOfLawQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_areas_of_law(
        **kwargs
    )

    @staticmethod
    def get_attorney_representation_type(
        attorney_representation_type_id,
        **kwargs
    ):

        """Attorney Representation Type Object for the given attorneyRepresentationTypeId.  


        Retrieve the specified attorney representation type.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_attorney_representation_type(
        attorney_representation_type_id,
        **kwargs
    )

    @staticmethod
    def get_attorney_representation_types(
        **kwargs
    ):

        """Attorney Representation Type Object.  


        Retrieve an attorney representation type using a keyword expression. Keyword expressions should be constructed according to the rules given above. ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below Schema section. Schema --> AttorneyRepresentationTypeQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_attorney_representation_types(
        **kwargs
    )

    @staticmethod
    def get_attorney_type(
        attorney_type_id,
        **kwargs
    ):

        """Attorney Type Object for given Attorney Type Id.  


        Retrieve a specified attorney type object.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_attorney_type(
        attorney_type_id,
        **kwargs
    )

    @staticmethod
    def get_attorney_types(
        **kwargs
    ):

        """Attorney Type Object.  


        Retrieve an attorney type using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below Schema section. Schema --> AttorneyTypeQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_attorney_types(
        **kwargs
    )

    @staticmethod
    def get_case_class(
        case_class_id,
        **kwargs
    ):

        """Case Class Object for the given Case Class Id.  


        Retrieve the specified case class.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_case_class(
        case_class_id,
        **kwargs
    )

    @staticmethod
    def get_case_relationship_type(
        case_relationship_type_id,
        **kwargs
    ):

        """Case Relationship Type Object for the given caseRelationshipTypeId.  


        Retrieve the specified case relationship type.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_case_relationship_type(
        case_relationship_type_id,
        **kwargs
    )

    @staticmethod
    def get_case_relationship_types(
        **kwargs
    ):

        """Case Relationship Type Object.  


        Retrieve an case relationship type using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CaseRelationshipTypeQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_case_relationship_types(
        **kwargs
    )

    @staticmethod
    def get_case_status(
        case_status_id,
        **kwargs
    ):

        """Returns the caseStatus information for the given caseStatusId.  


        Retrieve the specified case status.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_case_status(
        case_status_id,
        **kwargs
    )

    @staticmethod
    def get_case_status_group(
        case_status_group_id,
        **kwargs
    ):

        """Returns the caseStatusGroup information for the given caseStatusGroupId.  


        Retrieve the specified case status group.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_case_status_group(
        case_status_group_id,
        **kwargs
    )

    @staticmethod
    def get_case_status_groups(
        **kwargs
    ):

        """Case Status Group Object.  


        Retrieve a case status group using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CaseStatusGroupQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_case_status_groups(
        **kwargs
    )

    @staticmethod
    def get_case_type(
        case_type_id,
        **kwargs
    ):

        """CaseType Object for given Case Type Id.  


        Retrieve the specified case type.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_case_type(
        case_type_id,
        **kwargs
    )

    @staticmethod
    def get_case_type_group(
        case_type_group_id,
        **kwargs
    ):

        """CaseType Group for the given CaseType Group Id.  


        Retrieve the specified case type group.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_case_type_group(
        case_type_group_id,
        **kwargs
    )

    @staticmethod
    def get_case_type_groups(
        **kwargs
    ):

        """CaseTypeGroup Object.  


        Retrieve one or more case type groups using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CaseTypeGroupQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_case_type_groups(
        **kwargs
    )

    @staticmethod
    def get_case_types(
        **kwargs
    ):

        """Case Type Object.  


        Retrieve one or more case types using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CaseTypeQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_case_types(
        **kwargs
    )

    @staticmethod
    def get_cases_class(
        **kwargs
    ):

        """Case Class Object.  


        Retrieve one or more case classes using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CaseClassQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_cases_class(
        **kwargs
    )

    @staticmethod
    def get_cases_status(
        **kwargs
    ):

        """Case Status Object.  


        Retrieve a case status using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below Schema section. Schema --> CaseStatusQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_cases_status(
        **kwargs
    )

    @staticmethod
    def get_cause_of_action(
        cause_of_action_id,
        **kwargs
    ):

        """CauseOfAction Object for the given causeOfActionId.  


        Retrieve the specified cause of action.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_cause_of_action(
        cause_of_action_id,
        **kwargs
    )

    @staticmethod
    def get_cause_of_action_additional_data(
        cause_of_action_additional_data_id,
        **kwargs
    ):

        """CauseOfActionAdditionalData Object for the given causeOfActionAdditionalDataId.  


        Retrieve the specified cause of action additional data.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_cause_of_action_additional_data(
        cause_of_action_additional_data_id,
        **kwargs
    )

    @staticmethod
    def get_cause_of_action_group(
        cause_of_action_group_id,
        **kwargs
    ):

        """CauseOfActionGroup Object for the given causeOfActionGroupId.  


        Retrieve the specified cause of action group.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_cause_of_action_group(
        cause_of_action_group_id,
        **kwargs
    )

    @staticmethod
    def get_causes_of_action(
        **kwargs
    ):

        """CauseOfAction Object.  


        Retrieve a cause of action using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CauseOfActionQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_causes_of_action(
        **kwargs
    )

    @staticmethod
    def get_causes_of_action_additional_data(
        **kwargs
    ):

        """CauseOfActionAdditionaData Object.  


        Retrieve a cause of action additional data using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CauseOfActionAdditionalDataQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_causes_of_action_additional_data(
        **kwargs
    )

    @staticmethod
    def get_causes_of_action_group(
        **kwargs
    ):

        """CauseOfActionGroup Object.  


        Retrieve a cause of action group using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CauseOfActionGroupQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_causes_of_action_group(
        **kwargs
    )

    @staticmethod
    def get_charge(
        charge_id,
        **kwargs
    ):

        """Charge Object for the given chargeId.  


        Retrieve the specified charge.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_charge(
        charge_id,
        **kwargs
    )

    @staticmethod
    def get_charge_additional_data(
        charge_additional_data_id,
        **kwargs
    ):

        """Charge Additional Data Object for the given chargeAdditionalDataId.  


        Retrieve the specified charge additional data.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_charge_additional_data(
        charge_additional_data_id,
        **kwargs
    )

    @staticmethod
    def get_charge_degree(
        charge_degree_id,
        **kwargs
    ):

        """ChargeDegree Object for the given chargeDegreeId.  


        Retrieve the specified charge degree.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_charge_degree(
        charge_degree_id,
        **kwargs
    )

    @staticmethod
    def get_charge_group(
        charge_group_id,
        **kwargs
    ):

        """Charge Group Object for the given chargeGroupId.  


        Retrieve the specified charge group.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_charge_group(
        charge_group_id,
        **kwargs
    )

    @staticmethod
    def get_charge_groups(
        **kwargs
    ):

        """Charge Group Object.  


        Retrieve one or more charge groups using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> ChargeGroupQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_charge_groups(
        **kwargs
    )

    @staticmethod
    def get_charge_severity(
        charge_severity_id,
        **kwargs
    ):

        """ChargeSeverity Object for the given chargeSeverityId.  


        Retrieve the specified charge severity.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_charge_severity(
        charge_severity_id,
        **kwargs
    )

    @staticmethod
    def get_charges(
        **kwargs
    ):

        """Charge Object.  


        Retrieve one or more charges using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> ChargeQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_charges(
        **kwargs
    )

    @staticmethod
    def get_charges_additional_data(
        **kwargs
    ):

        """Charge Additional Data Object.  


        Retrieve additional information on a charge using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> ChargeAdditionalDataQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_charges_additional_data(
        **kwargs
    )

    @staticmethod
    def get_charges_degree(
        **kwargs
    ):

        """ChargeDegree Object.  


        Retrieve a charge degree using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> ChargeDegreeQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_charges_degree(
        **kwargs
    )

    @staticmethod
    def get_charges_severity(
        **kwargs
    ):

        """ChargeSeverity Object.  


        Retrieve a charge severity using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> ChargeSeverityQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_charges_severity(
        **kwargs
    )

    @staticmethod
    def get_court(
        court_id,
        **kwargs
    ):

        """Court Object for given courtId.  


        Retrieve information about a specified court.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_court(
        court_id,
        **kwargs
    )

    @staticmethod
    def get_court_location(
        court_location_id,
        **kwargs
    ):

        """Courthouse Object for given Court Location Id.  


        Contains the Court Location Object.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_court_location(
        court_location_id,
        **kwargs
    )

    @staticmethod
    def get_court_locations(
        **kwargs
    ):

        """Courthouse Object.  


        Retrieve the specified court location or court locations.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CourtLocationQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_court_locations(
        **kwargs
    )

    @staticmethod
    def get_court_locations_for_court(
        court_id,
        **kwargs
    ):

        """Associated Court Location for given courtId.  


        Retrieve the court locations associated with the specified court.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_court_locations_for_court(
        court_id,
        **kwargs
    )

    @staticmethod
    def get_court_service_status(
        court_service_status_id,
        **kwargs
    ):

        """Court Service Status Object for the given courtServiceStatusId.  


        Retrieve the court status of the specified court.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_court_service_status(
        court_service_status_id,
        **kwargs
    )

    @staticmethod
    def get_court_system(
        court_system_id,
        **kwargs
    ):

        """Court System Object for given courtSystemId.  


        Retrieve the specified court system.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_court_system(
        court_system_id,
        **kwargs
    )

    @staticmethod
    def get_court_systems(
        **kwargs
    ):

        """Court System Objects.  


        Retrieve information about the specified court system or court systems.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------|          | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CourtSystemQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_court_systems(
        **kwargs
    )

    @staticmethod
    def get_court_type(
        court_type_id,
        **kwargs
    ):

        """Court Type Object for given courtTypeId.  


        Retrieve the information concerning the specific court type.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_court_type(
        court_type_id,
        **kwargs
    )

    @staticmethod
    def get_court_types(
        **kwargs
    ):

        """Court Type Objects.  


        Retrieve court types recognized by UniCourt.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------|          | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CourtTypeQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_court_types(
        **kwargs
    )

    @staticmethod
    def get_courts(
        **kwargs
    ):

        """Court Objects.  


        Retrieve information about a specified court or courts.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------|          | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CourtQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_courts(
        **kwargs
    )

    @staticmethod
    def get_courts_for_court_location(
        court_location_id,
        **kwargs
    ):

        """Associated Court for given Court Location.  


        Retrieve the courts associated with the specified court location.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_courts_for_court_location(
        court_location_id,
        **kwargs
    )

    @staticmethod
    def get_courts_for_jurisdiction_geo(
        jurisdiction_geo_id,
        **kwargs
    ):

        """Associated Court for given Jurisdiction Geo.  


        Returns Associated Court for given Jurisdiction Geo.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_courts_for_jurisdiction_geo(
        jurisdiction_geo_id,
        **kwargs
    )

    @staticmethod
    def get_courts_service_status(
        **kwargs
    ):

        """Court Service Status Object.  


        Retrieve the status of one or more courts using a keyword expression.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> CourtServiceStatusQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_courts_service_status(
        **kwargs
    )

    @staticmethod
    def get_judge_type(
        judge_type_id,
        **kwargs
    ):

        """Judge Type Object for the given judgeTypeId.  


        Retrieve the specified judge type.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_judge_type(
        judge_type_id,
        **kwargs
    )

    @staticmethod
    def get_judge_types(
        **kwargs
    ):

        """Judge Type Object.  


        Retrieve a judge type using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> JudgeTypeQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_judge_types(
        **kwargs
    )

    @staticmethod
    def get_jurisdiction_geo(
        jurisdiction_geo_id,
        **kwargs
    ):

        """Jurisdiction Geo Object for given Jurisdiction Geo Id.  


        Retrieve the specified jurisdiction geography.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_jurisdiction_geo(
        jurisdiction_geo_id,
        **kwargs
    )

    @staticmethod
    def get_jurisdiction_geo_for_court(
        court_id,
        **kwargs
    ):

        """Jurisdiction Geo Objects for given courtId.  


        Retrieve the jurisdiction geography object for the specified court.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_jurisdiction_geo_for_court(
        court_id,
        **kwargs
    )

    @staticmethod
    def get_jurisdictions_geo(
        **kwargs
    ):

        """Jurisdiction Geo Object.  


        Retrieve one or more jurisdiction geographies using a keyword expression.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> JurisdictionGeoQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_jurisdictions_geo(
        **kwargs
    )

    @staticmethod
    def get_party_role(
        party_role_id,
        **kwargs
    ):

        """Party Role Object.  


        Retrieve the specified party role.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_party_role(
        party_role_id,
        **kwargs
    )

    @staticmethod
    def get_party_role_group(
        party_role_group_id,
        **kwargs
    ):

        """Party Role Group Object.  


        Retrieve the specified party role group.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_party_role_group(
        party_role_group_id,
        **kwargs
    )

    @staticmethod
    def get_party_role_groups(
        **kwargs
    ):

        """Party Role Group Object.  


        Retrieve a party role group using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> PartyRoleGroupQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_party_role_groups(
        **kwargs
    )

    @staticmethod
    def get_party_roles(
        **kwargs
    ):

        """Party Role Object.  


        Retrieve a party role using a keyword expression. Keyword expressions should be constructed according to the rules given above.  ## Logical Operators | Connector | Description  | Example | | ------| ------|------| | **AND** |Find data containing all connected terms.|**google AND facebook**| | **OR**  |Find data containing any connected term.| **order OR decision**| | **NOT** |Exclude data.| **google NOT apple**.| | **“[phrase]”** |Find an exact phrase.| **\"Google Inc”** | | **( … )** |Parenthesis may be used to group sets of terms of connectors.| **google (facebook OR apple)**.|  ### All Filter Query parameters supported for this API can be found in below schema section. Schema --> PartyRoleQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CourtStandardsApi(api_client).get_party_roles(
        **kwargs
    )



from unicourt.api.judge_analytics_api import JudgeAnalyticsApi
from unicourt import utils
class JudgeAnalytics:

    @staticmethod
    def get_norm_attorneys_associated_with_norm_judge(
        norm_judge_id,
        **kwargs
    ):

        """Attorneys Associated with the Judge.  


        Search for attorneys who have appeared before the specified judge using a keyword expression. ## Terms and Connectors | Connector | Schema   | Description  | Example | | ------| ------| ------|------| | **AND** ||Find analytics containing all connected terms. The word AND does not have to be capitalized.|**courtId:\"CORTV4vCEaKrhystBz\" AND courtLocationId:\"COLO6b82CkRqS846hx\"**| | **IN()** || Allows you to specify multiple values, for a limit of up to 10.| **courtLocationId IN (\"COLODj4BBVTho3pKpz\",\"COLOPUfJRhw5yPxgRi\")**| | **courtId** | Multiple Ids Allowed  |Find Analytics for a particular Court Object. | **courtId:\"CORTV4vCEaKrhystBz\"** | | **courtSystemId** | Multiple Ids Allowed  |Find Analytics for a particular Court System Object. | **courtSystemId:\"COSYACHBdMewtaG5DY\"** | | **courtTypeId** | Multiple Ids Allowed  |Find Analytics for a particular Court Type Object. | **courtTypeId:\"COTPm8jjc2PAydpFhq\"** | | **courtLocationId** | Multiple Ids Allowed  |Find Analytics for a particular Court Location Object. | **courtLocationId:\"COLO6b82CkRqS846hx\"** | | **caseTypeId** | Multiple Ids Allowed  |Find Analytics for a particular Case Type Object. | **caseTypeId:\"CTYPGkaW3aGJyKGyfn\"** | | **caseTypeGroupId** | Multiple Ids Allowed  |Find Analytics for a particular Case Type Group Object. | **caseTypeGroupId:\"CTYGBDwLfbbNBPBn5e\"** | | **areaOfLawId** | Multiple Ids Allowed  |Find Analytics for a particular Area Of Law Object. | **areaOfLawId:\"AOFL2UxEWfVmTPMyqf\"** | | **caseClassId** | Multiple Ids Allowed  |Find Analytics for a particular Case Class Category Object. | **caseClassId:\"CSCLNjbKTN7Yfo2wdb\"** | | **caseFiledDate** | Single Allowed |Find Analytics within a particular date range. | **caseFiledDate:[2018-05-08T00:00:00+00:00TO2019-05-08T00:00:00+00:00]** | | **JurisdictionGeo** | Multiple Ids Allowed  |Find Analytics within a particular Jurisdiction Geo. | **(JurisdictionGeo:(state:\"California\"))** | | **confidenceScore** | Single Allowed |Find Analytics for a given ConfidenceScore  | **confidenceScore:[0.3 TO \\*]** | | **bestMatch** | Single Allowed |True if the normEntity has the highest Confidence Score of all possible normEntities | **bestMatch:true** | <br> ## Example Query Query to get all attorneys associated with judge with norm id NJUDT7jCZyFNeLGpRq of all cases with case type id CTYPGkaW3aGJyKGyfn and case filed date between Jan 1st, 2017 to Nov 30th,2021<br> q=caseTypeId:\"CTYPGkaW3aGJyKGyfn\" AND caseFiledDate:[2017-01-01T00:00:00+00:00TO2021-11-30T00:00:00+00:00] <br><br>   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return JudgeAnalyticsApi(api_client).get_norm_attorneys_associated_with_norm_judge(
        norm_judge_id,
        **kwargs
    )

    @staticmethod
    def get_norm_judge_by_id(
        norm_judge_id,
        **kwargs
    ):

        """Norm Judge Details.  


        Retrieve the specified judge.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return JudgeAnalyticsApi(api_client).get_norm_judge_by_id(
        norm_judge_id,
        **kwargs
    )

    @staticmethod
    def get_norm_law_firms_associated_with_norm_judge(
        norm_judge_id,
        **kwargs
    ):

        """Law Firms Associated With the Judge.  


        Search for law firms that have appeared before the specified judge using a keyword expression. ## Terms and Connectors | Connector | Schema   | Description  | Example | | ------| ------| ------|------| | **AND** ||Find analytics containing all connected terms. The word AND does not have to be capitalized.|**courtId:\"CORTV4vCEaKrhystBz\" AND courtLocationId:\"COLOPUfJRhw5yPxgRi\"**| | **IN()** || Allows you to specify multiple values, for a limit of up to 10.| **courtLocationId IN (\"COLODj4BBVTho3pKpz\",\"COLOPUfJRhw5yPxgRi\")**| | **courtId** | Multiple Ids Allowed  |Find Analytics for a particular Court Object. | **courtId:\"CORTV4vCEaKrhystBz\"** | | **courtSystemId** | Multiple Ids Allowed  |Find Analytics for a particular Court System Object. | **courtSystemId:\"COSYACHBdMewtaG5DY\"** | | **courtTypeId** | Multiple Ids Allowed  |Find Analytics for a particular Court Type Object. | **courtTypeId:\"COTPm8jjc2PAydpFhq\"** | | **courtLocationId** | Multiple Ids Allowed  |Find Analytics for a particular Court Location Object. | **courtLocationId:\"COLO6b82CkRqS846hx\"** | | **caseTypeId** | Multiple Ids Allowed  |Find Analytics for a particular Case Type Object. | **caseTypeId:\"CTYPGkaW3aGJyKGyfn\"** | | **caseTypeGroupId** | Multiple Ids Allowed  |Find Analytics for a particular Case Type Group Object. | **caseTypeGroupId:\"CTYGBDwLfbbNBPBn5e\"** | | **areaOfLawId** | Multiple Ids Allowed  |Find Analytics for a particular Area Of Law Object. | **areaOfLawId:\"AOFL2UxEWfVmTPMyqf\"** | | **caseClassId** | Multiple Ids Allowed  |Find Analytics for a particular Case Class Category Object. | **caseClassId:\"CSCLNjbKTN7Yfo2wdb\"** | | **caseFiledDate** | Single Allowed  |Find Analytics within a particular date range. | **caseFiledDate:[2018-05-08T00:00:00+00:00TO2019-05-08T00:00:00+00:00]** | | **JurisdictionGeo**  | Multiple Ids Allowed |Find Analytics within a particular Jurisdiction Geo. | **(JurisdictionGeo:(state:\"California\"))** | | **confidenceScore** | Single Allowed |Find Analytics for a given ConfidenceScore  | **confidenceScore:[0.3 TO \\*]** | | **bestMatch** | Single Allowed |True if the normEntity has the highest Confidence Score of all possible normEntities | **bestMatch:true** | <br> ## Example Query Query to get all Law Firms associated with judge with norm id NJUDT7jCZyFNeLGpRq of all cases with case type id CTYPGkaW3aGJyKGyfn and case filed date between Jan 1st, 2017 to Nov 30th,2021<br> q=caseTypeId:\"CTYPGkaW3aGJyKGyfn\" AND caseFiledDate:[2017-01-01T00:00:00+00:00TO2021-11-30T00:00:00+00:00] <br><br>   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return JudgeAnalyticsApi(api_client).get_norm_law_firms_associated_with_norm_judge(
        norm_judge_id,
        **kwargs
    )

    @staticmethod
    def get_norm_parties_associated_with_norm_judge(
        norm_judge_id,
        **kwargs
    ):

        """Parties Associated with the Judge.  


        Search for parties that have appeared before the specified judge using a keyword expression. ## Terms and Connectors | Connector | Schema   | Description  | Example | | ------| ------| ------|------| | **AND** ||Find analytics containing all connected terms. The word AND does not have to be capitalized.|**courtId:\"CORTV4vCEaKrhystBz\" AND courtLocationId:\"COLO6b82CkRqS846hx\"**| | **IN()** || Allows you to specify multiple values, for a limit of up to 10.| **courtLocationId IN (\"COLODj4BBVTho3pKpz\",\"COLOPUfJRhw5yPxgRi\")**| | **courtId** | Multiple Ids Allowed  |Find Analytics for a particular Court Object. | **courtId:\"CORTV4vCEaKrhystBz\"** | | **courtSystemId** | Multiple Ids Allowed  |Find Analytics for a particular Court System Object. | **courtSystemId:\"COSYACHBdMewtaG5DY\"** | | **courtTypeId** | Multiple Ids Allowed  |Find Analytics for a particular Court Type Object. | **courtTypeId:\"COTPm8jjc2PAydpFhq\"** | | **courtLocationId** | Multiple Ids Allowed  |Find Analytics for a particular Court Location Object. | **courtLocationId:\"COLO6b82CkRqS846hx\"** | | **caseTypeId** | Multiple Ids Allowed  |Find Analytics for a particular Case Type Object. | **caseTypeId:\"CTYPGkaW3aGJyKGyfn\"** | | **caseTypeGroupId** | Multiple Ids Allowed  |Find Analytics for a particular Case Type Group Object. | **caseTypeGroupId:\"CTYGBDwLfbbNBPBn5e\"** | | **areaOfLawId** | Multiple Ids Allowed  |Find Analytics for a particular Area Of Law Object. | **areaOfLawId:\"AOFL2UxEWfVmTPMyqf\"** | | **caseClassId** | Multiple Ids Allowed  |Find Analytics for a particular Case Class Category Object. | **caseClassId:\"CSCLNjbKTN7Yfo2wdb\"** | | **caseFiledDate** | Single Allowed  |Find Analytics within a particular date range. | **caseFiledDate:[2018-05-08T00:00:00+00:00TO2019-05-08T00:00:00+00:00]** | | **JurisdictionGeo** | Multiple Ids Allowed  |Find Analytics within a particular Jurisdiction Geo. | **(JurisdictionGeo:(state:\"California\"))** | | **confidenceScore** | Single Allowed |Find Analytics for a given ConfidenceScore  | **confidenceScore:[0.3 TO \\*]** | | **bestMatch** | Single Allowed |True if the normEntity has the highest Confidence Score of all possible normEntities | **bestMatch:true** | <br> ## Example Query Query to get all Parties associated with judge with norm id NJUDT7jCZyFNeLGpRq of all cases with case type id CTYPGkaW3aGJyKGyfn and case filed date between Jan 1st, 2017 to Nov 30th,2021<br> q=caseTypeId:\"CTYPGkaW3aGJyKGyfn\" AND caseFiledDate:[2017-01-01T00:00:00+00:00TO2021-11-30T00:00:00+00:00] <br><br>   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return JudgeAnalyticsApi(api_client).get_norm_parties_associated_with_norm_judge(
        norm_judge_id,
        **kwargs
    )

    @staticmethod
    def search_normalized_judges(
        **kwargs
    ):

        """Judge search.  


        ### Search for a judge using a keyword expression.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return JudgeAnalyticsApi(api_client).search_normalized_judges(
        **kwargs
    )

    @staticmethod
    def search_normalized_judges_by_id(
        norm_judge_search_id,
        **kwargs
    ):

        """Norm judge search results for a given normJudgeSearchId.  


        ### Retrieve the desired search for a judge.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return JudgeAnalyticsApi(api_client).search_normalized_judges_by_id(
        norm_judge_search_id,
        **kwargs
    )



import os
from setuptools import setup, find_packages
here = os.path.abspath(os.path.dirname(__file__))
os.chdir(here)

NAME = "unicourt"
VERSION = "1.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["python_dateutil >= 2.5.3", "urllib3 >= 1.25.3"]

setup(
    name=NAME,
    version=VERSION,
    description="Python bindings for the UniCourt Enterprise APIs",
    author="UniCourt",
    author_email="support@unicourt.com",
    license="",
    url="https://unicourt.com/",
    project_urls={
        "Source": "https://github.com/UniCourt/enterprise-api-py-sdk/tree/main",
        "Documentation": "https://docs.unicourt.com/",
    },
    keywords=["UniCourt", "UniCourt Python Package",
              "UniCourt Enterprise APIs"],
    python_requires=">=3.6",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""The UniCourt Python Package provides simplified access to the UniCourt API for applications written in the Python programming language. Documentation of UniCourt's APIs can be found at docs.unicourt.com. API keys can be obtained by filling out the form here https://unicourt.com/contact-us/?c=sales&enterprise=1
    """
)



from unicourt.sdk.Callback import Callback


class TestCallBack:
    def test_get_callbacks():
        return Callback.get_callbacks(
            date='2022-03-08T00:00:00+00:00',
            status='IN_PROGRESS'
        )



from unicourt.api.case_docket_api import CaseDocketApi
from unicourt import utils
class CaseDocket:

    @staticmethod
    def get_attorney_associated_parties(
        attorney_id,
        **kwargs
    ):

        """Gets Associated Party details for a requested Attorney ID.  


        Retrieve the parties represented by the attorney with the specified attorneyId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_attorney_associated_parties(
        attorney_id,
        **kwargs
    )

    @staticmethod
    def get_attorney_by_id(
        attorney_id,
        **kwargs
    ):

        """Gets details for a requested Attorney ID.  


        Retrieve the attorney with the specified attorneyId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_attorney_by_id(
        attorney_id,
        **kwargs
    )

    @staticmethod
    def get_case(
        case_id,
        **kwargs
    ):

        """Gets case information for a requested Case ID.  


        Retrieve the case with the specified caseId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_case(
        case_id,
        **kwargs
    )

    @staticmethod
    def get_case_attorneys(
        case_id,
        **kwargs
    ):

        """Gets Attorneys for a requested Case ID.  


        Retrieve the attorneys in the case with the specified caseId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_case_attorneys(
        case_id,
        **kwargs
    )

    @staticmethod
    def get_case_docket_entries(
        case_id,
        **kwargs
    ):

        """Gets Docket Entries for a requested Case ID.  


        Retrieve the docket entries in the case with the specified caseId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_case_docket_entries(
        case_id,
        **kwargs
    )

    @staticmethod
    def get_case_hearings(
        case_id,
        **kwargs
    ):

        """Gets Hearings for a requested Case ID.  


        Gets Hearings for a requested Case ID.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_case_hearings(
        case_id,
        **kwargs
    )

    @staticmethod
    def get_case_judges(
        case_id,
        **kwargs
    ):

        """Gets Judges for a requested Case ID.  


        Retrieve the judges involved in the specified case.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_case_judges(
        case_id,
        **kwargs
    )

    @staticmethod
    def get_case_parties(
        case_id,
        **kwargs
    ):

        """Gets Parties for a requested Case ID.  


        Retrieve the parties involved in the case with the specified caseId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_case_parties(
        case_id,
        **kwargs
    )

    @staticmethod
    def get_case_related_cases(
        case_id,
        **kwargs
    ):

        """Gets Related Cases for a requested Case ID.  


        Retrieve cases that UniCourt has identified as related to the case with the specified caseId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_case_related_cases(
        case_id,
        **kwargs
    )

    @staticmethod
    def get_judge_by_id(
        judge_id,
        **kwargs
    ):

        """Gets details for a requested Judge ID.  


        Retrieve the judge with the specified judgeId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_judge_by_id(
        judge_id,
        **kwargs
    )

    @staticmethod
    def get_party_associated_attorneys(
        party_id,
        **kwargs
    ):

        """Gets Associated Attorney details for a requested Party ID.  


        Retrieve the attorneys in the case with the specified partyId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_party_associated_attorneys(
        party_id,
        **kwargs
    )

    @staticmethod
    def get_party_by_id(
        party_id,
        **kwargs
    ):

        """Gets details for a requested Party ID.  


        Retrieve the party with the specified partyId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_party_by_id(
        party_id,
        **kwargs
    )

    @staticmethod
    def get_primary_documents_for_docket_entries(
        case_id,
        docket_number,
        **kwargs
    ):

        """Gets Primary Documents of Docket Entries.  


        Retrieve the primary documents in the case with the specified caseId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_primary_documents_for_docket_entries(
        case_id,
        docket_number,
        **kwargs
    )

    @staticmethod
    def get_secondary_documents_for_docket_entries(
        case_id,
        docket_number,
        **kwargs
    ):

        """Gets Secondary Documents of Docket Entries.  


        Retrieve the secondary documents in the case with the specified caseId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseDocketApi(api_client).get_secondary_documents_for_docket_entries(
        case_id,
        docket_number,
        **kwargs
    )



"""
    UniCourt Enterprise APIs

    <button><a href=\"/enterpriseapi/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button>   # noqa: E501

    The version of the OpenAPI document: 
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from unicourt.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    OpenApiModel
)
from unicourt.exceptions import ApiAttributeError


def lazy_import():
    from unicourt.model.bar_source_data_administrative_actions_array_inner import BarSourceDataAdministrativeActionsArrayInner
    from unicourt.model.bar_source_data_advanced_degree_array_inner import BarSourceDataAdvancedDegreeArrayInner
    from unicourt.model.bar_source_data_bar_status_array_inner import BarSourceDataBarStatusArrayInner
    from unicourt.model.bar_source_data_board_certifications_array_inner import BarSourceDataBoardCertificationsArrayInner
    from unicourt.model.bar_source_data_committees_array_inner import BarSourceDataCommitteesArrayInner
    from unicourt.model.bar_source_data_court_history_array_inner import BarSourceDataCourtHistoryArrayInner
    from unicourt.model.bar_source_data_court_of_admissions import BarSourceDataCourtOfAdmissions
    from unicourt.model.bar_source_data_disciplinary_history_array_inner import BarSourceDataDisciplinaryHistoryArrayInner
    from unicourt.model.bar_source_data_discipline_summaries_array_inner import BarSourceDataDisciplineSummariesArrayInner
    from unicourt.model.bar_source_data_employment_history_array_inner import BarSourceDataEmploymentHistoryArrayInner
    from unicourt.model.bar_source_data_fees_options_array_inner import BarSourceDataFeesOptionsArrayInner
    from unicourt.model.bar_source_data_involvements_array_inner import BarSourceDataInvolvementsArrayInner
    from unicourt.model.bar_source_data_law_school_array_inner import BarSourceDataLawSchoolArrayInner
    from unicourt.model.bar_source_data_name import BarSourceDataName
    from unicourt.model.bar_source_data_open_action_status_array_inner import BarSourceDataOpenActionStatusArrayInner
    from unicourt.model.bar_source_data_other_jurisdiction_array_inner import BarSourceDataOtherJurisdictionArrayInner
    from unicourt.model.bar_source_data_public_hearing_array_inner import BarSourceDataPublicHearingArrayInner
    from unicourt.model.bar_source_data_reason_for_inactivation import BarSourceDataReasonForInactivation
    from unicourt.model.bar_source_data_related_cases_array_inner import BarSourceDataRelatedCasesArrayInner
    from unicourt.model.bar_source_data_source_info import BarSourceDataSourceInfo
    from unicourt.model.bar_source_data_statewide_grievance_committee_history_array_inner import BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner
    from unicourt.model.bar_source_data_status_history_array_inner import BarSourceDataStatusHistoryArrayInner
    from unicourt.model.bar_source_data_ten_year_discipline_array_inner import BarSourceDataTenYearDisciplineArrayInner
    globals()['BarSourceDataAdministrativeActionsArrayInner'] = BarSourceDataAdministrativeActionsArrayInner
    globals()['BarSourceDataAdvancedDegreeArrayInner'] = BarSourceDataAdvancedDegreeArrayInner
    globals()['BarSourceDataBarStatusArrayInner'] = BarSourceDataBarStatusArrayInner
    globals()['BarSourceDataBoardCertificationsArrayInner'] = BarSourceDataBoardCertificationsArrayInner
    globals()['BarSourceDataCommitteesArrayInner'] = BarSourceDataCommitteesArrayInner
    globals()['BarSourceDataCourtHistoryArrayInner'] = BarSourceDataCourtHistoryArrayInner
    globals()['BarSourceDataCourtOfAdmissions'] = BarSourceDataCourtOfAdmissions
    globals()['BarSourceDataDisciplinaryHistoryArrayInner'] = BarSourceDataDisciplinaryHistoryArrayInner
    globals()['BarSourceDataDisciplineSummariesArrayInner'] = BarSourceDataDisciplineSummariesArrayInner
    globals()['BarSourceDataEmploymentHistoryArrayInner'] = BarSourceDataEmploymentHistoryArrayInner
    globals()['BarSourceDataFeesOptionsArrayInner'] = BarSourceDataFeesOptionsArrayInner
    globals()['BarSourceDataInvolvementsArrayInner'] = BarSourceDataInvolvementsArrayInner
    globals()['BarSourceDataLawSchoolArrayInner'] = BarSourceDataLawSchoolArrayInner
    globals()['BarSourceDataName'] = BarSourceDataName
    globals()['BarSourceDataOpenActionStatusArrayInner'] = BarSourceDataOpenActionStatusArrayInner
    globals()['BarSourceDataOtherJurisdictionArrayInner'] = BarSourceDataOtherJurisdictionArrayInner
    globals()['BarSourceDataPublicHearingArrayInner'] = BarSourceDataPublicHearingArrayInner
    globals()['BarSourceDataReasonForInactivation'] = BarSourceDataReasonForInactivation
    globals()['BarSourceDataRelatedCasesArrayInner'] = BarSourceDataRelatedCasesArrayInner
    globals()['BarSourceDataSourceInfo'] = BarSourceDataSourceInfo
    globals()['BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner'] = BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner
    globals()['BarSourceDataStatusHistoryArrayInner'] = BarSourceDataStatusHistoryArrayInner
    globals()['BarSourceDataTenYearDisciplineArrayInner'] = BarSourceDataTenYearDisciplineArrayInner


class BarSourceData(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
        ('object',): {
            'max_length': 13,
        },
        ('admission_type',): {
            'max_length': 250,
        },
        ('appellate_court_district',): {
            'max_length': 250,
        },
        ('appellate_division_department',): {
            'max_length': 250,
        },
        ('attorney_group',): {
            'max_length': 250,
        },
        ('authorized',): {
            'max_length': 250,
        },
        ('bar_service_class',): {
            'max_length': 250,
        },
        ('bio',): {
            'max_length': 5000,
        },
        ('board_district',): {
            'max_length': 250,
        },
        ('circuit',): {
            'max_length': 250,
        },
        ('comments',): {
            'max_length': 250,
        },
        ('court_service_email',): {
            'max_length': 250,
        },
        ('district',): {
            'max_length': 250,
        },
        ('expiration_date',): {
            'max_length': 25,
        },
        ('firm_size',): {
            'max_length': 250,
        },
        ('firm_website',): {
            'max_length': 1000,
        },
        ('first_admitted_date',): {
            'max_length': 25,
        },
        ('home_county',): {
            'max_length': 250,
        },
        ('in_good_standing',): {
            'max_length': 250,
        },
        ('insurance',): {
            'max_length': 500,
        },
        ('judicial_district',): {
            'max_length': 250,
        },
        ('juris_type',): {
            'max_length': 250,
        },
        ('last_renewal_date',): {
            'max_length': 25,
        },
        ('license_type',): {
            'max_length': 250,
        },
        ('next_registration',): {
            'max_length': 25,
        },
        ('next_renewal_date',): {
            'max_length': 25,
        },
        ('parish',): {
            'max_length': 250,
        },
        ('position',): {
            'max_length': 250,
        },
        ('private_law_practice',): {
            'max_length': 250,
        },
        ('profile_last_certified',): {
            'max_length': 25,
        },
        ('status',): {
            'max_length': 500,
        },
        ('status_date',): {
            'max_length': 25,
        },
        ('undergraduate_school',): {
            'max_length': 250,
        },
        ('bar_law_firm',): {
            'max_length': 250,
        },
        ('years_of_practice',): {
            'max_length': 250,
        },
        ('status_hint',): {
            'max_length': 500,
        },
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'object': (str,),  # noqa: E501
            'administrative_actions_array': ([BarSourceDataAdministrativeActionsArrayInner],),  # noqa: E501
            'admission_type': (str, none_type,),  # noqa: E501
            'appellate_court_district': (str, none_type,),  # noqa: E501
            'appellate_division_department': (str, none_type,),  # noqa: E501
            'attorney_group': (str, none_type,),  # noqa: E501
            'authorized': (str, none_type,),  # noqa: E501
            'bar_service_class': (str, none_type,),  # noqa: E501
            'bio': (str, none_type,),  # noqa: E501
            'board_certifications_array': ([BarSourceDataBoardCertificationsArrayInner],),  # noqa: E501
            'board_district': (str, none_type,),  # noqa: E501
            'circuit': (str, none_type,),  # noqa: E501
            'comments': (str, none_type,),  # noqa: E501
            'committees_array': ([BarSourceDataCommitteesArrayInner],),  # noqa: E501
            'court_history_array': ([BarSourceDataCourtHistoryArrayInner],),  # noqa: E501
            'court_of_admissions': (BarSourceDataCourtOfAdmissions,),  # noqa: E501
            'court_service_email': (str, none_type,),  # noqa: E501
            'disciplinary_history_array': ([BarSourceDataDisciplinaryHistoryArrayInner],),  # noqa: E501
            'discipline_summaries_array': ([BarSourceDataDisciplineSummariesArrayInner],),  # noqa: E501
            'dismissals_array': ([str],),  # noqa: E501
            'district': (str, none_type,),  # noqa: E501
            'employment_history_array': ([BarSourceDataEmploymentHistoryArrayInner],),  # noqa: E501
            'expiration_date': (datetime, none_type,),  # noqa: E501
            'fees_options_array': ([BarSourceDataFeesOptionsArrayInner],),  # noqa: E501
            'firm_size': (str, none_type,),  # noqa: E501
            'firm_website': (str, none_type,),  # noqa: E501
            'first_admitted_date': (datetime, none_type,),  # noqa: E501
            'first_admitted_year': (int, none_type,),  # noqa: E501
            'home_county': (str, none_type,),  # noqa: E501
            'in_good_standing': (str, none_type,),  # noqa: E501
            'insurance': (str, none_type,),  # noqa: E501
            'involvements_array': ([BarSourceDataInvolvementsArrayInner],),  # noqa: E501
            'judicial_district': (str, none_type,),  # noqa: E501
            'juris_type': (str, none_type,),  # noqa: E501
            'languages_array': ([str],),  # noqa: E501
            'last_renewal_date': (datetime, none_type,),  # noqa: E501
            'law_school_array': ([BarSourceDataLawSchoolArrayInner],),  # noqa: E501
            'legal_speciality_array': ([str],),  # noqa: E501
            'license_type': (str, none_type,),  # noqa: E501
            'name': (BarSourceDataName,),  # noqa: E501
            'next_registration': (datetime, none_type,),  # noqa: E501
            'next_renewal_date': (datetime, none_type,),  # noqa: E501
            'open_action_status_array': ([BarSourceDataOpenActionStatusArrayInner],),  # noqa: E501
            'other_jurisdiction_array': ([BarSourceDataOtherJurisdictionArrayInner],),  # noqa: E501
            'other_name_array': ([str],),  # noqa: E501
            'parish': (str, none_type,),  # noqa: E501
            'pending_proceeding_array': ([str],),  # noqa: E501
            'position': (str, none_type,),  # noqa: E501
            'practice_area_array': ([str],),  # noqa: E501
            'practice_location_array': ([str],),  # noqa: E501
            'private_law_practice': (str, none_type,),  # noqa: E501
            'profile_last_certified': (datetime, none_type,),  # noqa: E501
            'public_hearing_array': ([BarSourceDataPublicHearingArrayInner],),  # noqa: E501
            'reason_for_inactivation': (BarSourceDataReasonForInactivation,),  # noqa: E501
            'sections_array': ([str],),  # noqa: E501
            'services_array': ([str],),  # noqa: E501
            'source_info': (BarSourceDataSourceInfo,),  # noqa: E501
            'statewide_grievance_committee_history_array': ([BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner],),  # noqa: E501
            'status': (str, none_type,),  # noqa: E501
            'status_date': (datetime, none_type,),  # noqa: E501
            'status_history_array': ([BarSourceDataStatusHistoryArrayInner],),  # noqa: E501
            'ten_year_discipline_array': ([BarSourceDataTenYearDisciplineArrayInner],),  # noqa: E501
            'undergraduate_school': (str, none_type,),  # noqa: E501
            'bar_law_firm': (str, none_type,),  # noqa: E501
            'years_of_practice': (str, none_type,),  # noqa: E501
            'clients_represented_array': ([str],),  # noqa: E501
            'status_hint': (str, none_type,),  # noqa: E501
            'advanced_degree_array': ([BarSourceDataAdvancedDegreeArrayInner],),  # noqa: E501
            'bar_status_array': ([BarSourceDataBarStatusArrayInner],),  # noqa: E501
            'related_cases_array': ([BarSourceDataRelatedCasesArrayInner],),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'object': 'object',  # noqa: E501
        'administrative_actions_array': 'administrativeActionsArray',  # noqa: E501
        'admission_type': 'admissionType',  # noqa: E501
        'appellate_court_district': 'appellateCourtDistrict',  # noqa: E501
        'appellate_division_department': 'appellateDivisionDepartment',  # noqa: E501
        'attorney_group': 'attorneyGroup',  # noqa: E501
        'authorized': 'authorized',  # noqa: E501
        'bar_service_class': 'barServiceClass',  # noqa: E501
        'bio': 'bio',  # noqa: E501
        'board_certifications_array': 'boardCertificationsArray',  # noqa: E501
        'board_district': 'boardDistrict',  # noqa: E501
        'circuit': 'circuit',  # noqa: E501
        'comments': 'comments',  # noqa: E501
        'committees_array': 'committeesArray',  # noqa: E501
        'court_history_array': 'courtHistoryArray',  # noqa: E501
        'court_of_admissions': 'courtOfAdmissions',  # noqa: E501
        'court_service_email': 'courtServiceEmail',  # noqa: E501
        'disciplinary_history_array': 'disciplinaryHistoryArray',  # noqa: E501
        'discipline_summaries_array': 'disciplineSummariesArray',  # noqa: E501
        'dismissals_array': 'dismissalsArray',  # noqa: E501
        'district': 'district',  # noqa: E501
        'employment_history_array': 'employmentHistoryArray',  # noqa: E501
        'expiration_date': 'expirationDate',  # noqa: E501
        'fees_options_array': 'feesOptionsArray',  # noqa: E501
        'firm_size': 'firmSize',  # noqa: E501
        'firm_website': 'firmWebsite',  # noqa: E501
        'first_admitted_date': 'firstAdmittedDate',  # noqa: E501
        'first_admitted_year': 'firstAdmittedYear',  # noqa: E501
        'home_county': 'homeCounty',  # noqa: E501
        'in_good_standing': 'inGoodStanding',  # noqa: E501
        'insurance': 'insurance',  # noqa: E501
        'involvements_array': 'involvementsArray',  # noqa: E501
        'judicial_district': 'judicialDistrict',  # noqa: E501
        'juris_type': 'jurisType',  # noqa: E501
        'languages_array': 'languagesArray',  # noqa: E501
        'last_renewal_date': 'lastRenewalDate',  # noqa: E501
        'law_school_array': 'lawSchoolArray',  # noqa: E501
        'legal_speciality_array': 'legalSpecialityArray',  # noqa: E501
        'license_type': 'licenseType',  # noqa: E501
        'name': 'name',  # noqa: E501
        'next_registration': 'nextRegistration',  # noqa: E501
        'next_renewal_date': 'nextRenewalDate',  # noqa: E501
        'open_action_status_array': 'openActionStatusArray',  # noqa: E501
        'other_jurisdiction_array': 'otherJurisdictionArray',  # noqa: E501
        'other_name_array': 'otherNameArray',  # noqa: E501
        'parish': 'parish',  # noqa: E501
        'pending_proceeding_array': 'pendingProceedingArray',  # noqa: E501
        'position': 'position',  # noqa: E501
        'practice_area_array': 'practiceAreaArray',  # noqa: E501
        'practice_location_array': 'practiceLocationArray',  # noqa: E501
        'private_law_practice': 'privateLawPractice',  # noqa: E501
        'profile_last_certified': 'profileLastCertified',  # noqa: E501
        'public_hearing_array': 'publicHearingArray',  # noqa: E501
        'reason_for_inactivation': 'reasonForInactivation',  # noqa: E501
        'sections_array': 'sectionsArray',  # noqa: E501
        'services_array': 'servicesArray',  # noqa: E501
        'source_info': 'sourceInfo',  # noqa: E501
        'statewide_grievance_committee_history_array': 'statewideGrievanceCommitteeHistoryArray',  # noqa: E501
        'status': 'status',  # noqa: E501
        'status_date': 'statusDate',  # noqa: E501
        'status_history_array': 'statusHistoryArray',  # noqa: E501
        'ten_year_discipline_array': 'tenYearDisciplineArray',  # noqa: E501
        'undergraduate_school': 'undergraduateSchool',  # noqa: E501
        'bar_law_firm': 'barLawFirm',  # noqa: E501
        'years_of_practice': 'yearsOfPractice',  # noqa: E501
        'clients_represented_array': 'clientsRepresentedArray',  # noqa: E501
        'status_hint': 'statusHint',  # noqa: E501
        'advanced_degree_array': 'advancedDegreeArray',  # noqa: E501
        'bar_status_array': 'barStatusArray',  # noqa: E501
        'related_cases_array': 'relatedCasesArray',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, administrative_actions_array, admission_type, appellate_court_district, appellate_division_department, attorney_group, authorized, bar_service_class, bio, board_certifications_array, board_district, circuit, comments, committees_array, court_history_array, court_of_admissions, court_service_email, disciplinary_history_array, discipline_summaries_array, dismissals_array, district, employment_history_array, expiration_date, fees_options_array, firm_size, firm_website, first_admitted_date, first_admitted_year, home_county, in_good_standing, insurance, involvements_array, judicial_district, juris_type, languages_array, last_renewal_date, law_school_array, legal_speciality_array, license_type, name, next_registration, next_renewal_date, open_action_status_array, other_jurisdiction_array, other_name_array, parish, pending_proceeding_array, position, practice_area_array, practice_location_array, private_law_practice, profile_last_certified, public_hearing_array, reason_for_inactivation, sections_array, services_array, source_info, statewide_grievance_committee_history_array, status, status_date, status_history_array, ten_year_discipline_array, undergraduate_school, bar_law_firm, years_of_practice, clients_represented_array, status_hint, advanced_degree_array, bar_status_array, related_cases_array, *args, **kwargs):  # noqa: E501
        """BarSourceData - a model defined in OpenAPI

        Args:
            administrative_actions_array ([BarSourceDataAdministrativeActionsArrayInner]):
            admission_type (str, none_type):
            appellate_court_district (str, none_type):
            appellate_division_department (str, none_type):
            attorney_group (str, none_type):
            authorized (str, none_type):
            bar_service_class (str, none_type):
            bio (str, none_type):
            board_certifications_array ([BarSourceDataBoardCertificationsArrayInner]):
            board_district (str, none_type):
            circuit (str, none_type):
            comments (str, none_type):
            committees_array ([BarSourceDataCommitteesArrayInner]):
            court_history_array ([BarSourceDataCourtHistoryArrayInner]):
            court_of_admissions (BarSourceDataCourtOfAdmissions):
            court_service_email (str, none_type):
            disciplinary_history_array ([BarSourceDataDisciplinaryHistoryArrayInner]):
            discipline_summaries_array ([BarSourceDataDisciplineSummariesArrayInner]):
            dismissals_array ([str]):
            district (str, none_type):
            employment_history_array ([BarSourceDataEmploymentHistoryArrayInner]):
            expiration_date (datetime, none_type):
            fees_options_array ([BarSourceDataFeesOptionsArrayInner]):
            firm_size (str, none_type):
            firm_website (str, none_type):
            first_admitted_date (datetime, none_type): The firstAdmittedDate is the date when an attorney was admitted to the bar for the very first time regardless of which U.S state.
            first_admitted_year (int, none_type):
            home_county (str, none_type):
            in_good_standing (str, none_type):
            insurance (str, none_type):
            involvements_array ([BarSourceDataInvolvementsArrayInner]):
            judicial_district (str, none_type):
            juris_type (str, none_type):
            languages_array ([str]):
            last_renewal_date (datetime, none_type):
            law_school_array ([BarSourceDataLawSchoolArrayInner]):
            legal_speciality_array ([str]):
            license_type (str, none_type):
            name (BarSourceDataName):
            next_registration (datetime, none_type):
            next_renewal_date (datetime, none_type):
            open_action_status_array ([BarSourceDataOpenActionStatusArrayInner]):
            other_jurisdiction_array ([BarSourceDataOtherJurisdictionArrayInner]):
            other_name_array ([str]):
            parish (str, none_type):
            pending_proceeding_array ([str]):
            position (str, none_type):
            practice_area_array ([str]):
            practice_location_array ([str]):
            private_law_practice (str, none_type):
            profile_last_certified (datetime, none_type):
            public_hearing_array ([BarSourceDataPublicHearingArrayInner]):
            reason_for_inactivation (BarSourceDataReasonForInactivation):
            sections_array ([str]):
            services_array ([str]):
            source_info (BarSourceDataSourceInfo):
            statewide_grievance_committee_history_array ([BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner]):
            status (str, none_type):
            status_date (datetime, none_type):
            status_history_array ([BarSourceDataStatusHistoryArrayInner]):
            ten_year_discipline_array ([BarSourceDataTenYearDisciplineArrayInner]):
            undergraduate_school (str, none_type):
            bar_law_firm (str, none_type):
            years_of_practice (str, none_type):
            clients_represented_array ([str]):
            status_hint (str, none_type):
            advanced_degree_array ([BarSourceDataAdvancedDegreeArrayInner]):
            bar_status_array ([BarSourceDataBarStatusArrayInner]):
            related_cases_array ([BarSourceDataRelatedCasesArrayInner]):

        Keyword Args:
            object (str): defaults to "BarSourceData"  # noqa: E501
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
        """

        object = kwargs.get('object', "BarSourceData")
        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.object = object
        self.administrative_actions_array = administrative_actions_array
        self.admission_type = admission_type
        self.appellate_court_district = appellate_court_district
        self.appellate_division_department = appellate_division_department
        self.attorney_group = attorney_group
        self.authorized = authorized
        self.bar_service_class = bar_service_class
        self.bio = bio
        self.board_certifications_array = board_certifications_array
        self.board_district = board_district
        self.circuit = circuit
        self.comments = comments
        self.committees_array = committees_array
        self.court_history_array = court_history_array
        self.court_of_admissions = court_of_admissions
        self.court_service_email = court_service_email
        self.disciplinary_history_array = disciplinary_history_array
        self.discipline_summaries_array = discipline_summaries_array
        self.dismissals_array = dismissals_array
        self.district = district
        self.employment_history_array = employment_history_array
        self.expiration_date = expiration_date
        self.fees_options_array = fees_options_array
        self.firm_size = firm_size
        self.firm_website = firm_website
        self.first_admitted_date = first_admitted_date
        self.first_admitted_year = first_admitted_year
        self.home_county = home_county
        self.in_good_standing = in_good_standing
        self.insurance = insurance
        self.involvements_array = involvements_array
        self.judicial_district = judicial_district
        self.juris_type = juris_type
        self.languages_array = languages_array
        self.last_renewal_date = last_renewal_date
        self.law_school_array = law_school_array
        self.legal_speciality_array = legal_speciality_array
        self.license_type = license_type
        self.name = name
        self.next_registration = next_registration
        self.next_renewal_date = next_renewal_date
        self.open_action_status_array = open_action_status_array
        self.other_jurisdiction_array = other_jurisdiction_array
        self.other_name_array = other_name_array
        self.parish = parish
        self.pending_proceeding_array = pending_proceeding_array
        self.position = position
        self.practice_area_array = practice_area_array
        self.practice_location_array = practice_location_array
        self.private_law_practice = private_law_practice
        self.profile_last_certified = profile_last_certified
        self.public_hearing_array = public_hearing_array
        self.reason_for_inactivation = reason_for_inactivation
        self.sections_array = sections_array
        self.services_array = services_array
        self.source_info = source_info
        self.statewide_grievance_committee_history_array = statewide_grievance_committee_history_array
        self.status = status
        self.status_date = status_date
        self.status_history_array = status_history_array
        self.ten_year_discipline_array = ten_year_discipline_array
        self.undergraduate_school = undergraduate_school
        self.bar_law_firm = bar_law_firm
        self.years_of_practice = years_of_practice
        self.clients_represented_array = clients_represented_array
        self.status_hint = status_hint
        self.advanced_degree_array = advanced_degree_array
        self.bar_status_array = bar_status_array
        self.related_cases_array = related_cases_array
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, administrative_actions_array, admission_type, appellate_court_district, appellate_division_department, attorney_group, authorized, bar_service_class, bio, board_certifications_array, board_district, circuit, comments, committees_array, court_history_array, court_of_admissions, court_service_email, disciplinary_history_array, discipline_summaries_array, dismissals_array, district, employment_history_array, expiration_date, fees_options_array, firm_size, firm_website, first_admitted_date, first_admitted_year, home_county, in_good_standing, insurance, involvements_array, judicial_district, juris_type, languages_array, last_renewal_date, law_school_array, legal_speciality_array, license_type, name, next_registration, next_renewal_date, open_action_status_array, other_jurisdiction_array, other_name_array, parish, pending_proceeding_array, position, practice_area_array, practice_location_array, private_law_practice, profile_last_certified, public_hearing_array, reason_for_inactivation, sections_array, services_array, source_info, statewide_grievance_committee_history_array, status, status_date, status_history_array, ten_year_discipline_array, undergraduate_school, bar_law_firm, years_of_practice, clients_represented_array, status_hint, advanced_degree_array, bar_status_array, related_cases_array, *args, **kwargs):  # noqa: E501
        """BarSourceData - a model defined in OpenAPI

        Args:
            administrative_actions_array ([BarSourceDataAdministrativeActionsArrayInner]):
            admission_type (str, none_type):
            appellate_court_district (str, none_type):
            appellate_division_department (str, none_type):
            attorney_group (str, none_type):
            authorized (str, none_type):
            bar_service_class (str, none_type):
            bio (str, none_type):
            board_certifications_array ([BarSourceDataBoardCertificationsArrayInner]):
            board_district (str, none_type):
            circuit (str, none_type):
            comments (str, none_type):
            committees_array ([BarSourceDataCommitteesArrayInner]):
            court_history_array ([BarSourceDataCourtHistoryArrayInner]):
            court_of_admissions (BarSourceDataCourtOfAdmissions):
            court_service_email (str, none_type):
            disciplinary_history_array ([BarSourceDataDisciplinaryHistoryArrayInner]):
            discipline_summaries_array ([BarSourceDataDisciplineSummariesArrayInner]):
            dismissals_array ([str]):
            district (str, none_type):
            employment_history_array ([BarSourceDataEmploymentHistoryArrayInner]):
            expiration_date (datetime, none_type):
            fees_options_array ([BarSourceDataFeesOptionsArrayInner]):
            firm_size (str, none_type):
            firm_website (str, none_type):
            first_admitted_date (datetime, none_type): The firstAdmittedDate is the date when an attorney was admitted to the bar for the very first time regardless of which U.S state.
            first_admitted_year (int, none_type):
            home_county (str, none_type):
            in_good_standing (str, none_type):
            insurance (str, none_type):
            involvements_array ([BarSourceDataInvolvementsArrayInner]):
            judicial_district (str, none_type):
            juris_type (str, none_type):
            languages_array ([str]):
            last_renewal_date (datetime, none_type):
            law_school_array ([BarSourceDataLawSchoolArrayInner]):
            legal_speciality_array ([str]):
            license_type (str, none_type):
            name (BarSourceDataName):
            next_registration (datetime, none_type):
            next_renewal_date (datetime, none_type):
            open_action_status_array ([BarSourceDataOpenActionStatusArrayInner]):
            other_jurisdiction_array ([BarSourceDataOtherJurisdictionArrayInner]):
            other_name_array ([str]):
            parish (str, none_type):
            pending_proceeding_array ([str]):
            position (str, none_type):
            practice_area_array ([str]):
            practice_location_array ([str]):
            private_law_practice (str, none_type):
            profile_last_certified (datetime, none_type):
            public_hearing_array ([BarSourceDataPublicHearingArrayInner]):
            reason_for_inactivation (BarSourceDataReasonForInactivation):
            sections_array ([str]):
            services_array ([str]):
            source_info (BarSourceDataSourceInfo):
            statewide_grievance_committee_history_array ([BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner]):
            status (str, none_type):
            status_date (datetime, none_type):
            status_history_array ([BarSourceDataStatusHistoryArrayInner]):
            ten_year_discipline_array ([BarSourceDataTenYearDisciplineArrayInner]):
            undergraduate_school (str, none_type):
            bar_law_firm (str, none_type):
            years_of_practice (str, none_type):
            clients_represented_array ([str]):
            status_hint (str, none_type):
            advanced_degree_array ([BarSourceDataAdvancedDegreeArrayInner]):
            bar_status_array ([BarSourceDataBarStatusArrayInner]):
            related_cases_array ([BarSourceDataRelatedCasesArrayInner]):

        Keyword Args:
            object (str): defaults to "BarSourceData"  # noqa: E501
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
        """

        object = kwargs.get('object', "BarSourceData")
        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.object = object
        self.administrative_actions_array = administrative_actions_array
        self.admission_type = admission_type
        self.appellate_court_district = appellate_court_district
        self.appellate_division_department = appellate_division_department
        self.attorney_group = attorney_group
        self.authorized = authorized
        self.bar_service_class = bar_service_class
        self.bio = bio
        self.board_certifications_array = board_certifications_array
        self.board_district = board_district
        self.circuit = circuit
        self.comments = comments
        self.committees_array = committees_array
        self.court_history_array = court_history_array
        self.court_of_admissions = court_of_admissions
        self.court_service_email = court_service_email
        self.disciplinary_history_array = disciplinary_history_array
        self.discipline_summaries_array = discipline_summaries_array
        self.dismissals_array = dismissals_array
        self.district = district
        self.employment_history_array = employment_history_array
        self.expiration_date = expiration_date
        self.fees_options_array = fees_options_array
        self.firm_size = firm_size
        self.firm_website = firm_website
        self.first_admitted_date = first_admitted_date
        self.first_admitted_year = first_admitted_year
        self.home_county = home_county
        self.in_good_standing = in_good_standing
        self.insurance = insurance
        self.involvements_array = involvements_array
        self.judicial_district = judicial_district
        self.juris_type = juris_type
        self.languages_array = languages_array
        self.last_renewal_date = last_renewal_date
        self.law_school_array = law_school_array
        self.legal_speciality_array = legal_speciality_array
        self.license_type = license_type
        self.name = name
        self.next_registration = next_registration
        self.next_renewal_date = next_renewal_date
        self.open_action_status_array = open_action_status_array
        self.other_jurisdiction_array = other_jurisdiction_array
        self.other_name_array = other_name_array
        self.parish = parish
        self.pending_proceeding_array = pending_proceeding_array
        self.position = position
        self.practice_area_array = practice_area_array
        self.practice_location_array = practice_location_array
        self.private_law_practice = private_law_practice
        self.profile_last_certified = profile_last_certified
        self.public_hearing_array = public_hearing_array
        self.reason_for_inactivation = reason_for_inactivation
        self.sections_array = sections_array
        self.services_array = services_array
        self.source_info = source_info
        self.statewide_grievance_committee_history_array = statewide_grievance_committee_history_array
        self.status = status
        self.status_date = status_date
        self.status_history_array = status_history_array
        self.ten_year_discipline_array = ten_year_discipline_array
        self.undergraduate_school = undergraduate_school
        self.bar_law_firm = bar_law_firm
        self.years_of_practice = years_of_practice
        self.clients_represented_array = clients_represented_array
        self.status_hint = status_hint
        self.advanced_degree_array = advanced_degree_array
        self.bar_status_array = bar_status_array
        self.related_cases_array = related_cases_array
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



import os
from unicourt.model.pacer_credential_request import PacerCredentialRequest
from unicourt.sdk.PACERCredential import PACERCredential


class TestPacerCredentials:
    def test_add_pacer_credential():
        pacer_credential_request = PacerCredentialRequest(
            pacer_user_id=os.getenv("PACER_USER_ID"),
            default_pacer_client_code=os.getenv("PACER_CLIENT_CODE"),
            password="TEST_PASSWORD",
        )
        return PACERCredential.add_pacer_credential(
            pacer_credential_request=pacer_credential_request)

    def test_get_pacer_credential():
        return PACERCredential.get_pacer_credential(
            page_number=1)

    def test_get_pacer_credential_by_id():
        return PACERCredential.get_pacer_credential_by_id(
            pacer_user_id=os.getenv("PACER_USER_ID"),
        )

    def test_remove_pacer_credential_by_id():
        return PACERCredential.remove_pacer_credential_by_id(
            pacer_user_id=os.getenv("PACER_USER_ID")
        )



from unicourt.api.party_analytics_api import PartyAnalyticsApi
from unicourt import utils
class PartyAnalytics:

    @staticmethod
    def get_norm_attorneys_associated_with_norm_party(
        norm_party_id,
        **kwargs
    ):

        """Attorneys that represented the Party.  


        Search for attorneys who have represented a given party using a keyword expression. ## Terms and Connectors | Connector | Schema   | Description  | Example | | ------| ------| ------|------| | **AND** ||Find analytics containing all connected terms. The word AND does not have to be capitalized.|**courtId:\"CORTV4vCEaKrhystBz\" AND courtLocationId:\"COLO6b82CkRqS846hx\"**| | **IN()** || Allows you to specify multiple values, for a limit of up to 10.| **courtId IN (\"CORTV4vCEaKrhystBz\",\"CORTYsomR6GiiiPovp\")**| | **courtId** | Multiple Ids Allowed |Find Analytics for a particular Court Object. | **courtId:\"CORTV4vCEaKrhystBz\"** | | **courtSystemId** | Multiple Ids Allowed |Find Analytics for a particular Court System Object. | **courtSystemId:\"COSYACHBdMewtaG5DY\"** | | **courtTypeId** | Multiple Ids Allowed |Find Analytics for a particular Court Type Object. | **courtTypeId:\"COTPm8jjc2PAydpFhq\"** | | **courtLocationId** | Multiple Ids Allowed |Find Analytics for a particular Court Location Object. | **courtLocationId:\"COLO6b82CkRqS846hx\"** | | **caseTypeId** | Multiple Ids Allowed |Find Analytics for a particular Case Type Object. | **caseTypeId:\"CTYPGkaW3aGJyKGyfn\"** | | **caseTypeGroupId** | Multiple Ids Allowed |Find Analytics for a particular Case Type Group Object. | **caseTypeGroupId:\"CTYGBDwLfbbNBPBn5e\"** | | **areaOfLawId** | Multiple Ids Allowed |Find Analytics for a particular Area Of Law Object. | **areaOfLawId:\"AOFL2UxEWfVmTPMyqf\"** | | **caseClassId** | Multiple Ids Allowed |Find Analytics for a particular Case Class Category Object. | **caseClassId:\"CSCLNjbKTN7Yfo2wdb\"** | | **partyRoleId** | Multiple Ids Allowed |Find Analytics for a particular Party Type Object. | **partyRoleId:\"PTYRiP8nMgPxBsPc5i\"** | | **partyRoleGroupId** | Multiple Ids Allowed |Find Analytics for a particular Party Type Group Object. | **partyRoleGroupId:\"PTYGBnjxbx6tKNfVEP\"** | | **attorneyPartyRoleId** | Multiple Ids Allowed |Find Analytics for a particular Attorney Party Type Object. | **attorneyPartyRoleId:\"PTYRiP8nMgPxBsPc5i\"** | | **attorneyPartyRoleGroupId** | Multiple Ids Allowed |Find Analytics for a particular Attorney Party Type Group Object. | **attorneyPartyRoleGroupId:\"PTYGBnjxbx6tKNfVEP\"** | | **caseFiledDate** | Single Allowed  |Find Analytics within a particular date range. | **caseFiledDate:[2018-05-08T00:00:00+00:00TO2019-05-08T00:00:00+00:00]** | | **JurisdictionGeo** | Multiple filters Allowed |Find Analytics within a particular Jurisdiction Geo. | **(JurisdictionGeo:(state:\"California\"))** | | **confidenceScore** | Single Allowed |Find Analytics for a given ConfidenceScore  | **confidenceScore:[0.3 TO \\*]** | | **bestMatch** | Single Allowed |True if the normEntity has the highest Confidence Score of all possible normEntities | **bestMatch:true** | <br> ## Example Query Query to get all attorneys associated with Party with norm id NORGrPmQyLdx9NGHcT of all cases with case type id CTYPGkaW3aGJyKGyfn and  case filed date between Jan 1st, 2017 to Nov 30th,2021<br> q=caseTypeId:\"CTYPGkaW3aGJyKGyfn\" AND caseFiledDate:[2017-01-01T00:00:00+00:00TO2021-11-30T00:00:00+00:00] <br><br>   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PartyAnalyticsApi(api_client).get_norm_attorneys_associated_with_norm_party(
        norm_party_id,
        **kwargs
    )

    @staticmethod
    def get_norm_judges_associated_with_norm_party(
        norm_party_id,
        **kwargs
    ):

        """Judges Faced By the Party.  


        Search for judges before whom a party has appeared using a keyword expression. <br><br> ## Terms and Connectors | Connector | Schema   | Description  | Example | | ------| ------| ------|------| | **AND** ||Find analytics containing all connected terms. The word AND does not have to be capitalized.|**courtId:\"CORTV4vCEaKrhystBz\" AND courtLocationId:\"COLO6b82CkRqS846hx\"**| | **IN()** || Allows you to specify multiple values, for a limit of up to 10.| **courtId IN (\"CORTV4vCEaKrhystBz\",\"CORTYsomR6GiiiPovp\")**| | **courtId** | Multiple Ids Allowed |Find Analytics for a particular Court Object. | **courtId:\"CORTV4vCEaKrhystBz\"** | | **courtSystemId** | Multiple Ids Allowed |Find Analytics for a particular Court System Object. | **courtSystemId:\"COSYACHBdMewtaG5DY\"** | | **courtTypeId** | Multiple Ids Allowed |Find Analytics for a particular Court Type Object. | **courtTypeId:\"COTPm8jjc2PAydpFhq\"** | | **courtLocationId** | Multiple Ids Allowed |Find Analytics for a particular Court Location Object. | **courtLocationId:\"COLO6b82CkRqS846hx\"** | | **caseTypeId** | Multiple Ids Allowed |Find Analytics for a particular Case Type Object. | **caseTypeId:\"CTYPGkaW3aGJyKGyfn\"** | | **caseTypeGroupId** | Multiple Ids Allowed |Find Analytics for a particular Case Type Group Object. | **caseTypeGroupId:\"CTYGBDwLfbbNBPBn5e\"** | | **areaOfLawId** | Multiple Ids Allowed |Find Analytics for a particular Area Of Law Object. | **areaOfLawId:\"AOFL2UxEWfVmTPMyqf\"** | | **caseClassId** | Multiple Ids Allowed |Find Analytics for a particular Case Class Category Object. | **caseClassId:\"CSCLNjbKTN7Yfo2wdb\"** | | **caseFiledDate** | Single Allowed  |Find Analytics within a particular date range. | **caseFiledDate:[2018-05-08T00:00:00+00:00TO2019-05-08T00:00:00+00:00]** | | **JurisdictionGeo** | Multiple filters Allowed |Find Analytics within a particular Jurisdiction Geo. | **(JurisdictionGeo:(state:\"California\"))** | | **confidenceScore** | Single Allowed |Find Analytics for a given ConfidenceScore  | **confidenceScore:[0.3 TO \\*]** | | **bestMatch** | Single Allowed |True if the normEntity has the highest Confidence Score of all possible normEntities | **bestMatch:true** | <br> ## Example Query Query to get all judges associated with Party with norm id NORGrPmQyLdx9NGHcT of all cases with case type id CTYPGkaW3aGJyKGyfn and  case filed date between Jan 1st, 2017 to Nov 30th,2021<br> q=caseTypeId:\"CTYPGkaW3aGJyKGyfn\" AND caseFiledDate:[2017-01-01T00:00:00+00:00TO2021-11-30T00:00:00+00:00] <br><br>   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PartyAnalyticsApi(api_client).get_norm_judges_associated_with_norm_party(
        norm_party_id,
        **kwargs
    )

    @staticmethod
    def get_norm_law_firms_associated_with_norm_party(
        norm_party_id,
        **kwargs
    ):

        """Law Firms that represented the Party.  


        Search for law firms that have represented the specified party using a keyword expression. ## Terms and Connectors | Connector | Schema   | Description  | Example | | ------| ------| ------|------| | **AND** ||Find analytics containing all connected terms. The word AND does not have to be capitalized.|**courtId:\"CORTV4vCEaKrhystBz\" AND courtLocationId:\"COLO6b82CkRqS846hx\"**| | **IN()** || Allows you to specify multiple values, for a limit of up to 10.| **courtId IN (\"CORTV4vCEaKrhystBz\",\"CORTYsomR6GiiiPovp\")**| | **courtId** | Multiple Ids Allowed |Find Analytics for a particular Court Object. | **courtId:\"CORTV4vCEaKrhystBz\"** | | **courtSystemId** | Multiple Ids Allowed |Find Analytics for a particular Court System Object. | **courtSystemId:\"COSYACHBdMewtaG5DY\"** | | **courtTypeId** | Multiple Ids Allowed |Find Analytics for a particular Court Type Object. | **courtTypeId:\"COTPm8jjc2PAydpFhq\"** | | **courtLocationId** | Multiple Ids Allowed |Find Analytics for a particular Court Location Object. | **courtLocationId:\"COLO6b82CkRqS846hx\"** | | **caseTypeId** | Multiple Ids Allowed |Find Analytics for a particular Case Type Object. | **caseTypeId:\"CTYPGkaW3aGJyKGyfn\"** | | **caseTypeGroupId** | Multiple Ids Allowed |Find Analytics for a particular Case Type Group Object. | **caseTypeGroupId:\"CTYGBDwLfbbNBPBn5e\"** | | **areaOfLawId** | Multiple Ids Allowed |Find Analytics for a particular Area Of Law Object. | **areaOfLawId:\"AOFL2UxEWfVmTPMyqf\"** | | **caseClassId** | Multiple Ids Allowed |Find Analytics for a particular Case Class Category Object. | **caseClassId:\"CSCLNjbKTN7Yfo2wdb\"** | | **partyRoleId** | Multiple Ids Allowed |Find Analytics for a particular Party Type Object. | **partyRoleId:\"PTYRiP8nMgPxBsPc5i\"** | | **partyRoleGroupId** | Multiple Ids Allowed |Find Analytics for a particular Party Type Group Object. | **partyRoleGroupId:\"PTYGBnjxbx6tKNfVEP\"** | | **attorneyPartyRoleId** | Multiple Ids Allowed |Find Analytics for a particular Attorney Party Type Object. | **attorneyPartyRoleId:\"PTYRiP8nMgPxBsPc5i\"** | | **attorneyPartyRoleGroupId** | Multiple Ids Allowed |Find Analytics for a particular Attorney Party Type Group Object. | **attorneyPartyRoleGroupId:\"PTYGBnjxbx6tKNfVEP\"** | | **caseFiledDate** | Single Allowed |Find Analytics within a particular date range. | **caseFiledDate:[2018-05-08T00:00:00+00:00TO2019-05-08T00:00:00+00:00]** | | **JurisdictionGeo** | Multiple filters Allowed |Find Analytics within a particular Jurisdiction Geo. | **(JurisdictionGeo:(state:\"California\"))** | | **confidenceScore** | Single Allowed |Find Analytics for a given ConfidenceScore  | **confidenceScore:[0.3 TO \\*]** | | **bestMatch** | Single Allowed |True if the normEntity has the highest Confidence Score of all possible normEntities | **bestMatch:true** | <br> ## Example Query Query to get all lawfirms associated with Party with norm id NORGrPmQyLdx9NGHcT of all cases with case type id CTYPGkaW3aGJyKGyfn and  case filed date between Jan 1st, 2017 to Nov 30th,2021<br> q=caseTypeId:\"CTYPGkaW3aGJyKGyfn\" AND caseFiledDate:[2017-01-01T00:00:00+00:00TO2021-11-30T00:00:00+00:00]   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PartyAnalyticsApi(api_client).get_norm_law_firms_associated_with_norm_party(
        norm_party_id,
        **kwargs
    )

    @staticmethod
    def get_norm_party_by_id(
        norm_party_id,
        **kwargs
    ):

        """Norm Party Details.  


        Retrieve the specified party.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PartyAnalyticsApi(api_client).get_norm_party_by_id(
        norm_party_id,
        **kwargs
    )

    @staticmethod
    def search_normalized_parties(
        **kwargs
    ):

        """Party search.  


        ### Search for a party using a keyword expression.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PartyAnalyticsApi(api_client).search_normalized_parties(
        **kwargs
    )

    @staticmethod
    def search_normalized_parties_by_id(
        norm_party_search_id,
        **kwargs
    ):

        """Norm party search results for a given normPartySearchId.  


        ### Retrieve a search for a party.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PartyAnalyticsApi(api_client).search_normalized_parties_by_id(
        norm_party_search_id,
        **kwargs
    )
